@@ -14,6 +14,7 @@ from .report import cnv_report as cnv_report_command
 from .report import coverage_qc_report as coverage_qc_report_command
 from .report import delivery_report as delivery_report_command
 from .report import gene_fusion_report as gene_fusion_report_command
+from .report import report as report_command
 from .research import research as research_command
 from .user import user as user_command
 from .variants import variants as variants_command
@@ -35,6 +36,7 @@ load.add_command(panel_command)
 load.add_command(user_command)
 load.add_command(research_command)
 load.add_command(variants_command)
+load.add_command(report_command)
 load.add_command(delivery_report_command)
 load.add_command(cnv_report_command)
 load.add_command(coverage_qc_report_command)
