@@ -11,6 +11,7 @@ madeline_file = "demo/madeline.xml"
 ped_file = "demo/643594.ped"
 load_file = "demo/643594.config.yaml"
 cancer_load_file = "demo/cancer.load_config.yaml"
+rnafusion_load_file = "demo/rnafusion.load_config.yaml"
 
 clinical_snv_file = "demo/643594.clinical.vcf.gz"
 research_snv_file = "demo/643594.research.vcf.gz"
@@ -32,6 +33,7 @@ panelapp_panel_path = pkg_resources.resource_filename("scout", panelapp_file)
 madeline_path = pkg_resources.resource_filename("scout", madeline_file)
 load_path = pkg_resources.resource_filename("scout", load_file)
 cancer_load_path = pkg_resources.resource_filename("scout", cancer_load_file)
+rnafusion_load_path = pkg_resources.resource_filename("scout", rnafusion_load_file)
 
 clinical_snv_path = pkg_resources.resource_filename("scout", clinical_snv_file)
 clinical_sv_path = pkg_resources.resource_filename("scout", clinical_sv_file)
