@@ -338,7 +338,8 @@ def case(store, institute_obj, case_obj):
         "case": case_obj,
         "status_class": STATUS_MAP.get(case_obj["status"]),
         "other_causatives": [
-            var for var in store.check_causatives(case_obj=case_obj, limit_genes=limit_genes)
+            var
+            for var in store.case_matching_causatives(case_obj=case_obj, limit_genes=limit_genes)
         ],
         "managed_variants": [
             var for var in store.check_managed(case_obj=case_obj, limit_genes=limit_genes)
@@ -919,8 +920,12 @@ def add_case_group(store, current_user, institute_id, case_name, group=None):
     Returns:
         updated_case    (InsertOneResult)
     """
+    try:
+        institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+    except Exception:
+        flash(f"Could not find a case named {case_name} for institute {institute_id}", "warning")
+        return
 
-    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
     link = url_for("cases.case", institute_id=institute_id, case_name=case_name)
     user_obj = store.user(current_user.email)
 
