@@ -4,6 +4,7 @@ import json
 import logging
 import os.path
 import shutil
+from io import BytesIO
 from operator import itemgetter
 
 from cairosvg import svg2png
@@ -23,7 +24,7 @@ from flask import (
 from flask_login import current_user
 
 from scout.constants import CUSTOM_CASE_REPORTS
-from scout.server.extensions import beacon, store
+from scout.server.extensions import beacon, phenopacketapi, store
 from scout.server.utils import (
     html_to_pdf_file,
     institute_and_case,
@@ -362,6 +363,68 @@ def phenotypes(institute_id, case_name, phenotype_id=None):
     return redirect("#".join([case_url, "phenotypes_panel"]))
 
 
+@cases_bp.route("/<institute_id>/<case_name>/phenotype_export", methods=["POST"])
+def phenotype_export(institute_id, case_name):
+    """Export phenopacket JSON for affected individual."""
+    _, case_obj = institute_and_case(store, institute_id, case_name)
+    case_url = url_for(".case", institute_id=institute_id, case_name=case_name)
+
+    phenopacket_json = phenopacketapi.phenopacket_from_case(case_obj)
+
+    if not phenopacket_json:
+        return redirect("#".join([case_url, "phenotypes_panel"]))
+
+    file_name = "_".join(
+        [
+            case_obj["display_name"],
+            datetime.datetime.now().strftime("%Y-%m-%d"),
+            "scout_phenopacket.json",
+        ]
+    )
+    json_file = BytesIO(bytes(phenopacket_json, "utf-8"))
+
+    return send_file(
+        json_file,
+        mimetype="application/json",
+        as_attachment=True,
+        download_name=file_name,
+    )
+
+
+@cases_bp.route("/<institute_id>/<case_name>/phenotype_import", methods=["POST"])
+def phenotype_import(institute_id, case_name):
+    """Import phenopacket JSON for affected individual."""
+    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+    user_obj = store.user(current_user.email)
+    case_url = url_for(".case", institute_id=institute_id, case_name=case_name)
+    phenopacket = None
+
+    phenopacket_file = request.files["phenopacket_file"]
+    phenopacket_hash = request.form.get("phenopacket_hash")
+
+    if not phenopacket_file and not phenopacket_hash:
+        flash("Please provide a phenotype file (json or hash format)", "warning")
+        return redirect("#".join([case_url, "phenotypes_panel"]))
+
+    if phenopacket_file:
+        phenopacket = phenopacketapi.file_import(phenopacket_file)
+
+    phenopacket_hash = request.form.get("phenopacket_hash")
+
+    if phenopacket_hash:
+        phenopacket = phenopacketapi.get_hash(phenopacket_hash)
+
+    if phenopacket is None:
+        flash("An error occurred while retrieving Phenopacket info", "warning")
+
+    else:
+        phenopacketapi.add_phenopacket_to_case(
+            store, institute_obj, case_obj, user_obj, case_url, phenopacket
+        )
+
+    return redirect("#".join([case_url, "phenotypes_panel"]))
+
+
 @cases_bp.route("/<institute_id>/<case_name>/phenotypes/actions", methods=["POST"])
 def phenotypes_actions(institute_id, case_name):
     """Perform actions on multiple phenotypes."""
@@ -494,18 +557,27 @@ def assign(institute_id, case_name, user_id=None, inactivate=False):
     return redirect(request.referrer)
 
 
+@cases_bp.route("/api/v1/cases", defaults={"institute_id": None})
 @cases_bp.route("/api/v1/<institute_id>/cases")
 def caselist(institute_id):
     """Search for cases for autocompletion"""
     query = request.args.get("query")
     if query is None:
         return abort(500)
-    display_names = sorted(
-        [
-            case["display_name"]
-            for case in store.cases(owner=institute_id, name_query="case:" + query)
-        ]
-    )
+
+    matching_cases = store.cases(owner=institute_id, name_query="case:" + query)
+    display_names = []
+    if institute_id:  # called from case page, where institute_id is provided
+        display_names = sorted([case["display_name"] for case in matching_cases])
+    else:  # called from gene panel page, where institute_id is NOT provided
+        user_institutes_ids = [inst["_id"] for inst in user_institutes(store, current_user)]
+        display_names = sorted(
+            [
+                " - ".join([case["owner"], case["display_name"]])
+                for case in matching_cases
+                if case["owner"] in user_institutes_ids
+            ]
+        )
     json_terms = [{"name": "{}".format(display_name)} for display_name in display_names]
 
     return jsonify(json_terms)
@@ -628,108 +700,40 @@ def check_case(institute_id, case_name):
     return redirect(request.referrer)
 
 
-@cases_bp.route("/<institute_id>/<case_name>/delivery-report")
-def delivery_report(institute_id, case_name):
-    """Display delivery report."""
-    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
-    if case_obj.get("delivery_report") is None:
-        return abort(404)
+@cases_bp.route("/<institute_id>/<case_name>/report/<report_type>")
+def custom_report(institute_id, case_name, report_type):
+    """Display/download a custom report for a case"""
 
-    date_str = request.args.get("date")
-    if date_str is not None:
-        delivery_report = None
+    report_path = None
+    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+
+    date_str = request.args.get("date")  # Provided only when downloading old delivery reports
+    if date_str is None:
+        report_path = case_obj.get(report_type)
+    else:
         for analysis_data in case_obj.get("analyses", []):
             if str(analysis_data["date"].date()) == date_str:
-                delivery_report = analysis_data["delivery_report"]
-        if delivery_report is None:
-            return abort(404)
-    else:
-        delivery_report = case_obj["delivery_report"]
+                report_path = analysis_data["delivery_report"]
 
-    out_dir = os.path.abspath(os.path.dirname(delivery_report))
-    filename = os.path.basename(delivery_report)
-
-    report_format = request.args.get("format", "html")
-    if report_format == "pdf":
-        try:  # file could not be available
-            html_file = open(delivery_report, "r")
-            source_code = html_file.read()
-
-            bytes_file = html_to_pdf_file(source_code, "portrait", 300)
-            file_name = "_".join(
-                [
-                    case_obj["display_name"],
-                    datetime.datetime.now().strftime("%Y-%m-%d"),
-                    "scout_delivery.pdf",
-                ]
-            )
-            return send_file(
-                bytes_file,
-                download_name=file_name,
-                mimetype="application/pdf",
-                as_attachment=True,
-            )
-        except Exception as ex:
-            flash(
-                "An error occurred while downloading delivery report {} -- {}".format(
-                    delivery_report, ex
-                ),
-                "warning",
-            )
-            LOG.error(
-                f"An error occurred while downloading delivery report {delivery_report} -- {ex}"
-            )
-
-    return send_from_directory(out_dir, filename)
-
-
-@cases_bp.route("/<institute_id>/<case_name>/cnv-report")
-def cnv_report(institute_id, case_name):
-    """Display CNV report."""
-    data = controllers.multiqc(store, institute_id, case_name)
-    if data["case"].get("cnv_report") is None:
+    if report_path is None:
         return abort(404)
-    out_dir = os.path.abspath(os.path.dirname(data["case"]["cnv_report"]))
-    filename = os.path.basename(data["case"]["cnv_report"])
-    return send_from_directory(out_dir, filename)
 
-
-@cases_bp.route("/<institute_id>/<case_name>/gene-fusion-report/<report_type>")
-def gene_fusion_report(institute_id, case_name, report_type):
-    """Download gene fusion report"""
-    _, case_obj = institute_and_case(store, institute_id, case_name)
-    report_path = case_obj.get(report_type)
-    if report_path is None or report_type not in CUSTOM_CASE_REPORTS:
-        return abort(404)
     out_dir = os.path.abspath(os.path.dirname(report_path))
     filename = os.path.basename(report_path)
-    return send_from_directory(out_dir, filename)
 
-
-@cases_bp.route("/<institute_id>/<case_name>/coverage-qc-report")
-def coverage_qc_report(institute_id, case_name):
-    """Display coverage and qc report."""
-    _, case_obj = institute_and_case(store, institute_id, case_name)
-    coverage_qc_report = case_obj.get("coverage_qc_report")
-
-    if coverage_qc_report is None:
-        return abort(404)
-
-    report_format = request.args.get("format", "html")
-
-    out_dir = os.path.abspath(os.path.dirname(coverage_qc_report))
-    filename = os.path.basename(coverage_qc_report)
-
-    if report_format == "pdf":
+    if request.args.get("report_format") == "pdf":
         try:
-            with open(os.path.abspath(coverage_qc_report), "r") as html_file:
+            with open(os.path.abspath(report_path), "r") as html_file:
                 source_code = html_file.read()
+                if CUSTOM_CASE_REPORTS[report_type]["format"] == "YAML":
+                    source_code = "<html><code><pre>" + source_code + "</pre></code></html>"
+
                 bytes_file = html_to_pdf_file(source_code, "landscape", 300)
                 file_name = "_".join(
                     [
                         case_obj["display_name"],
                         datetime.datetime.now().strftime("%Y-%m-%d"),
-                        "coverage_qc_report.pdf",
+                        ".".join([report_type, "pdf"]),
                     ]
                 )
                 return send_file(
@@ -741,7 +745,7 @@ def coverage_qc_report(institute_id, case_name):
         except Exception as ex:
             flash(
                 "An error occurred while converting report to PDF: {} -- {}".format(
-                    coverage_qc_report, ex
+                    report_type, ex
                 ),
                 "warning",
             )
@@ -950,17 +954,6 @@ def vcf2cytosure(institute_id, case_name, individual_id):
     return send_from_directory(outdir, filename, download_name=download_name, as_attachment=True)
 
 
-@cases_bp.route("/<institute_id>/<case_name>/multiqc")
-def multiqc(institute_id, case_name):
-    """Load multiqc report for the case."""
-    data = controllers.multiqc(store, institute_id, case_name)
-    if data["case"].get("multiqc") is None:
-        return abort(404)
-    out_dir = os.path.abspath(os.path.dirname(data["case"]["multiqc"]))
-    filename = os.path.basename(data["case"]["multiqc"])
-    return send_from_directory(out_dir, filename)
-
-
 @cases_bp.route(
     "/<institute_id>/<case_name>/<individual>/upd_regions_images/<image>",
     methods=["GET", "POST"],
