@@ -135,7 +135,7 @@ def causatives(institute_obj, request):
 
     causatives = []
 
-    for variant_obj in store.check_causatives(institute_obj=institute_obj, limit_genes=hgnc_id):
+    for variant_obj in store.institute_causatives(institute_obj=institute_obj, limit_genes=hgnc_id):
         variant_genes = variant_obj.get("genes", [])
         if variant_obj["category"] in ["snv", "cancer"]:
             update_representative_gene(
@@ -151,7 +151,6 @@ def causatives(institute_obj, request):
             "status": case_obj.get("status"),
             "partial_causatives": case_obj.get("partial_causatives", []),
         }
-
         causatives.append(variant_obj)
 
     return causatives
@@ -346,6 +345,7 @@ def update_institute_settings(store, institute_obj, form):
         cohorts=cohorts,
         loqusdb_ids=loqusdb_ids,
         alamut_key=form.get("alamut_key"),
+        alamut_institution=form.get("alamut_institution"),
         check_show_all_vars=form.get("check_show_all_vars"),
     )
     return updated_institute
