@@ -786,6 +786,10 @@ def parse_variant(
         variant_obj, user_institutes(store, current_user)
     )
 
+    variant_obj["matching_ranked"] = store.get_matching_manual_ranked_variants(
+        variant_obj, user_institutes(store, current_user), exclude_cases=[case_obj["_id"]]
+    )
+
     variant_genes = variant_obj.get("genes")
     if variant_genes:
         variant_obj.update(predictions(variant_genes))
